==> easeiot-datacenter-mysqlrds-1.1.3-20240914.070130-5-sources.jar: com/easesource/iot/datacenter/openservice/dao/MeasDataInsFreezeCurveDao.java <==
package com.easesource.iot.datacenter.openservice.dao;

import com.easesource.data.bean.Pager;
import com.easesource.data.bean.Sorter;
import com.easesource.data.jdbc.mybatis.CrudMapper;
import com.easesource.iot.datacenter.openservice.entity.MeasDataCumFreezeCurveDo;
import com.easesource.iot.datacenter.openservice.entity.MeasDataInsFreezeCurveDo;
import com.easesource.iot.datacenter.openservice.entity.MeasDataInsFreezeCurveVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 *
 * @author Nick Zhang
 * @date 2019-04-08
 */
public interface MeasDataInsFreezeCurveDao extends CrudMapper<MeasDataInsFreezeCurveDo, Long> {

    /**
     * 批量更新
     * @param measDataInsFreezeCurveDoList
     *          瞬时量曲线数据实体列表
     * @return
     */
    int batchInsertOrUpdate(@Param("list") List<MeasDataInsFreezeCurveDo> measDataInsFreezeCurveDoList);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据实体
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          瞬时量曲线数据
     */
    MeasDataInsFreezeCurveDo getByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          瞬时量曲线数据
     */
    MeasDataInsFreezeCurveVo getMeasDataInsFreezeCurveVoByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 查询结果个数
     *
     * @param params
     *          查询参数
     * @return
     *          查询结果个数
     */
    int getMeasDataInsFreezeCurveVoCount(@Param("params") Map<String, Object> params);

    /**
     * 查询结果列表
     *
     * @param params
     *          查询参数
     * @param sorter
     *          排序
     * @param pager
     *          分页
     * @return
     *          查询结果列表
     */
    List<MeasDataInsFreezeCurveVo> getMeasDataInsFreezeCurveVoList(@Param("params") Map<String, Object> params, @Param("sorter") Sorter sorter, @Param("pager") Pager pager);

    void deleteByMeasPointIdAndGmtMeasFreeze(@Param("measPointIds") Set<Long> measPointIds, @Param("gmtMeasFreeze")  long gmtMeasFreeze, @Param("gmtMeasFreezeEnd")  long gmtMeasFreezeEnd);

    Integer getMeasDataInsFreezeCurveVo(@Param("measPointIds") Set<Long> measPointIds, @Param("gmtMeasFreeze")  long gmtMeasFreeze, @Param("gmtMeasFreezeEnd")  long gmtMeasFreezeEnd);

}

==> easeiot-datacenter-mysqlrds-1.1.3-20250304.091358-1-sources.jar: com/easesource/iot/datacenter/openservice/dao/MeasDataInsFreezeCurveDao.java <==
package com.easesource.iot.datacenter.openservice.dao;

import com.easesource.data.bean.Pager;
import com.easesource.data.bean.Sorter;
import com.easesource.data.jdbc.mybatis.CrudMapper;
import com.easesource.iot.datacenter.openservice.entity.MeasDataCumFreezeCurveDo;
import com.easesource.iot.datacenter.openservice.entity.MeasDataInsFreezeCurveDo;
import com.easesource.iot.datacenter.openservice.entity.MeasDataInsFreezeCurveVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 *
 * @author Nick Zhang
 * @date 2019-04-08
 */
public interface MeasDataInsFreezeCurveDao extends CrudMapper<MeasDataInsFreezeCurveDo, Long> {

    /**
     * 批量更新
     * @param measDataInsFreezeCurveDoList
     *          瞬时量曲线数据实体列表
     * @return
     */
    int batchInsertOrUpdate(@Param("list") List<MeasDataInsFreezeCurveDo> measDataInsFreezeCurveDoList);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据实体
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          瞬时量曲线数据
     */
    MeasDataInsFreezeCurveDo getByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 通过量测点标识和量测项编码获取量测点最新数据视图
     *
     * @param measPointId
     *          量测点标识
     * @param measItemCode
     *          量测项编码
     * @param gmtMeasFreeze
     *          量测曲线时间
     * @return
     *          瞬时量曲线数据
     */
    MeasDataInsFreezeCurveVo getMeasDataInsFreezeCurveVoByMeasPointIdAndMeasItemCodeAndGmtMeasFreeze(@Param("measPointId") Long measPointId, @Param("measItemCode") String measItemCode, @Param("gmtMeasFreeze") long gmtMeasFreeze);

    /**
     * 查询结果个数
     *
     * @param params
     *          查询参数
     * @return
     *          查询结果个数
     */
    int getMeasDataInsFreezeCurveVoCount(@Param("params") Map<String, Object> params);

    /**
     * 查询结果列表
     *
     * @param params
     *          查询参数
     * @param sorter
     *          排序
     * @param pager
     *          分页
     * @return
     *          查询结果列表
     */
    List<MeasDataInsFreezeCurveVo> getMeasDataInsFreezeCurveVoList(@Param("params") Map<String, Object> params, @Param("sorter") Sorter sorter, @Param("pager") Pager pager);

    void deleteByMeasPointIdAndGmtMeasFreeze(@Param("measPointIds") Set<Long> measPointIds, @Param("gmtMeasFreeze")  long gmtMeasFreeze, @Param("gmtMeasFreezeEnd")  long gmtMeasFreezeEnd);

    Integer getMeasDataInsFreezeCurveVo(@Param("measPointIds") Set<Long> measPointIds, @Param("gmtMeasFreeze")  long gmtMeasFreeze, @Param("gmtMeasFreezeEnd")  long gmtMeasFreezeEnd);

    List<MeasDataInsFreezeCurveVo> getMeasDataInsFreezeCurveListByList(@Param("measPointIds") List<Long> measPointIds,@Param("measItemCodeList") List<String> measItemCodeList,@Param("gmtMeasFreezeStart") long gmtMeasFreezeStart,@Param("gmtMeasFreezeEnd") long gmtMeasFreezeEnd,@Param("sorter") Sorter sorter);
}
